.\" Copyright (c) 1990 Carnegie Mellon University
.\" All Rights Reserved.
.\" 
.\" Permission to use, copy, modify and distribute this software and its
.\" documentation is hereby granted, provided that both the copyright
.\" notice and this permission notice appear in all copies of the
.\" software, derivative works or modified versions, and any portions
.\" thereof, and that both notices appear in supporting documentation.
.\"
.\" THE SOFTWARE IS PROVIDED "AS IS" AND CARNEGIE MELLON UNIVERSITY
.\" DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL
.\" IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS.  IN NO EVENT
.\" SHALL CARNEGIE MELLON UNIVERSITY BE LIABLE FOR ANY SPECIAL, DIRECT,
.\" INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER
.\" RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF
.\" CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
.\" CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
.\"
.\" Users of this software agree to return to Carnegie Mellon any
.\" improvements or extensions that they make and grant Carnegie the
.\" rights to redistribute these changes.
.\"
.\" Export of this software is permitted only after complying with the
.\" regulations of the U.S. Deptartment of Commerce relating to the
.\" Export of Technical Data.
.\"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
.\" HISTORY
.\" $Log:	wantwrite.3,v $
.\" Revision 1.2  90/12/12  15:59:39  mja
.\" 	Add copyright/disclaimer for distribution.
.\" 
.\" 13-Nov-86  Andi Swimmer (andi) at Carnegie-Mellon University
.\" 	Revised for 4.3.
.\" 
.\" 22-Oct-81  Fil Alleva (faa) at Carnegie-Mellon University
.\" 	Added check for error return from 
.\" 	.IR getstr (3) 
.\" 	to prevent infinite loop.
.\" 
.\" 06-Dec-79  Steven Shafer (sas) at Carnegie-Mellon University
.\" 	Created.
.\" 
.TH WANTWRITE 3 10/27/81
.CM 3
.SH "NAME"
wantwrite, fwantwrite \- open file for writing
.SH "SYNOPSIS"
.B
#include <stdio.h>
.br
.B
#include <sys/file>
.sp
.B
int wantwrite (searchlist,filename,fullname,prompt,warn);
.br
.B
char *searchlist,*filename,*fullname,*prompt;
.br
.B
int warn;
.sp
.B
FILE *fwantwrite (searchlist,filename,fullname,prompt,warn);
.br
.B
char *searchlist,*filename,*fullname,*prompt;
.br
.B
int warn;
.SH "DESCRIPTION"
.I
Wantwrite
attempts to open a file for output, asking the user
for an alternate file name over and over again until
a file is successfully opened for writing.
.sp
.I
Searchlist
is a list of directories which may be contain the file,
with the directory names separated by colons.
.I
Filename
is the name of the file the program wishes to open;
if
.I
filename
is the
null string, then the user will be asked
immediately for the name of a file to open.
When a file is opened, the complete filename is copied
into
.I
fullname,
which must be a string provided by the user.
.sp
For each directory whose name appears in
.I
searchlist,
the complete filename will be formed by contatenating a slash (/)
and
.I
filename.
Then, an attempt will be made to
.IR creat (2)
the file.
If
.I
warn
is TRUE, then a check will first be made to ensure that the file
does not already exist.
If it does, the user will be asked
if he wants to delete it; if he says "no", then no attempt will
be made to
.I
creat (2)
the file and searching will continue with the next directory.
.sp
If no attempt to
.IR open (2)
the file is successful, then an error message is printed along
with the message
.I
prompt,
and the user can type in an alternate file name.
The new file name
is searched for using the same
.I
searchlist.
The user may also indicate that no file is acceptable; in this case,
.I
wantwrite
will return an error indication.
.sp
.I
Fwantwrite
is the same as
.I
wantwrite,
but uses
.IR fopen (3)
to create a buffered file, and returns a FILE pointer.
.SH "SEE ALSO"
.IR open (3), 
.IR fopen (3), 
.IR searchp (3), 
.IR wantread (3), 
.IR fwantread (3)
.SH "DIAGNOSTICS"
.I
Wantwrite
returns \-1 on error; otherwise the file
descriptor
of the successfully created file.
.sp
.I
Fwantwrite
returns 0 on error, or the FILE pointer of the successfully
created file.
.SH "BUGS"
.I
Fullname
must be long enough to hold the complete filename of the opened file.
.sp
There should be a way to change the value of
.I
searchlist
if the search for a file is unsuccessful.
